import { ColorModeRef } from "./color-mode.utils";
export type { ColorModeRef };
export interface ColorModeOptions {
    initialColorMode?: ColorModeRef;
    useSystemColorMode?: boolean;
}
export declare type ColorModeContext = {
    colorMode: ColorModeRef;
    toggleColorMode: () => void;
};
/** Injects color mode into component instance */
export declare const useColorMode: () => ColorModeContext;
/**
 * Change value based on color mode.
 *
 * @param lightValue the light mode value
 * @param darkValue the dark mode value
 *
 * @example
 *
 * ```js
 * const Icon = useColorModeValue(MoonIcon, SunIcon)
 * ```
 */
export declare function useColorModeValue<TLight = unknown, TDark = unknown>(lightValue: TLight, darkValue: TDark): import("vue").Ref<any>;
//# sourceMappingURL=color-mode-provider.d.ts.map